# Copyright (C) 2022 ArianBOT

version = "4.5.5"
copyright = " Arsein Copyright (C) 2022 arianabasi Team ArianBOT \n\n"
Arian = "ArianBOT"


class copyright_Arsein:
    arsein = print(
        f"Arsein library version {version}\n{copyright}\n☞ library Arsein: https://github.com/Arseinlibrary/Arsein__library.git\n\nدر حال فعال شدن کمی صبور باشید...\n")
    print(" ")
    print(". . . . . . . . . . . ")



from libraryArsein.encoder import encoderjson
import json
from json import dumps

class meghdar:
	def __init__(self,auth):
		self.Auth = auth
		self.enc = encoderjson(auth)

	def return_json(self,Json):
		return dumps({"api_version":"5","auth": self.Auth,"data_enc":self.enc.encrypt(dumps(Json))})



class server_bot:
    matnadress = [
        'https://messengerg2c26.iranlms.ir',
        'https://messengerg2c1.iranlms.ir',
        "https://messengerg2c33.iranlms.ir",
        'https://messengerg2c22.iranlms.ir',
        'https://messengerg2c55.iranlms.ir',
        'https://messengerg2c57.iranlms.ir',
        'https://messengerg2c15.iranlms.ir',
        'https://messengerg2c16.iranlms.ir',
        'https://messengerg2c46.iranlms.ir',
        'https://messengerg2c39.iranlms.ir',
        'https://messengerg2c40.iranlms.ir',
        'https://messengerg2c41.iranlms.ir',
        'https://messengerg2c6.iranlms.ir',
        'https://messengerg2c7.iranlms.ir',
        'https://messengerg2c63.iranlms.ir',
        'https://messengerg2c31.iranlms.ir',
        'https://messengerg2c3.iranlms.ir',
        'https://messengerg2c101.iranlms.ir',
        'https://messengerg2c146.iranlms.ir',
        'https://messengerg2c115.iranlms.ir',
        'https://messengerg2c59.iranlms.ir',
        'https://messengerg2c27.iranlms.ir',
        'https://messengerg2c110.iranlms.ir',
        'https://messengerg2c159.iranlms.ir'
    ]

    filesadress = [
        'https://messengerg2c26.iranlms.ir'
        'https://messengerg2c39.iranlms.ir',
        'https://messengerg2c7.iranlms.ir',
        'https://messengerg2c17.iranlms.ir',
        'https://messengerg2c46.iranlms.ir'
    ]



import aiohttp
import libraryArsein.encoder
from libraryArsein.encoder import encoderjson
import json
from json import dumps, loads


async def http(s,auth,js):
	enc = encoderjson(auth)
	async with aiohttp.ClientSession() as session:
		async with session.post(s, data=dumps({"api_version":"5","auth": auth,"data_enc":enc.encrypt(dumps(js))}) , headers = {'Content-Type': 'application/json'}) as response:
			Post =  await response.text()
			return Post


async def httpfiles(s,dade,head):
	async with aiohttp.ClientSession() as session:
		async with session.post(s, data= dade  , headers = head) as response:
			Post =  await response.text()
			return Post
